/**
 * @file
 * Provides Outlayer Packery loader.
 */

(function (Drupal, Packery, _db) {

  'use strict';

  /**
   * Outlayer utility functions.
   *
   * @namespace
   */
  Drupal.outLayer.packery = _db.extend(Drupal.outLayer || {}, {

    onClass: 'packery',

    load: function (el) {
      var me = this;

      me.$el = el;
      me.options = _db.parse(el.getAttribute('data-outlayer-packery')) || {};

      // Prepare, define aspect ratio before laying out, and initialize.
      me.prepare(el);

      me.$instance = new Packery(el, me.options);

      // Runs update(), including on resize event, only if nobody helps.
      if (me.isUnGridStack) {
        me.buildOut(el);
      }

      me.cleanUp(el);
    }

  });

  /**
   * Attaches Outlayer behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.outLayerPackery = {
    attach: function (context) {
      if ('length' in context) {
        context = context[0];
      }

      var me = Drupal.outLayer.packery;
      var elms = context.querySelectorAll('.outlayer--packery:not(.is-packery-on)');
      if (elms.length > 0) {
        _db.once(_db.forEach(elms, me.init.bind(me), context));
      }
    }
  };

}(Drupal, Packery, dBlazy));
